@@ -1,11 +1,11 @@
 import logging
 from typing import Any, Dict, List, Tuple, Type
 
-from django.db import models
+from django.db import models, transaction
 from django.db.models.query import QuerySet
 from ninja_extra.shortcuts import get_object_or_none
 
-from easy.response import BaseApiResponse
+from easy.exception import BaseAPIException
 
 logger = logging.getLogger(__name__)
 
@@ -19,7 +19,15 @@ class CrudModel(object):
             if isinstance(_field, models.ManyToManyField)
         )
 
-    def __separate_payload(self, payload: Dict) -> Tuple[Dict, Dict]:
+    # @property
+    # def model_join(self):
+    #     """If configured to retrieve m2m by join"""
+    #     if hasattr(self.model, "Meta"):
+    #         return getattr(self.model.Meta, "model_join", True)
+    #     else:
+    #         return True
+
+    def _separate_payload(self, payload: Dict) -> Tuple[Dict, Dict]:
         m2m_fields = {}
         local_fields = {}
         for _field in payload.keys():
@@ -27,45 +35,56 @@ class CrudModel(object):
             if model_field in self.m2m_fields_list:
                 m2m_fields.update({_field: payload[_field]})
             else:
-                local_fields.update({_field: payload[_field]})
+                # Handling FK fields ( append _id in the end)
+                if self.model._meta.get_field(_field).is_relation:
+                    if not f"{_field}".endswith("_id"):
+                        local_fields.update({f"{_field}_id": payload[_field]})
+                else:
+                    local_fields.update({_field: payload[_field]})
         return local_fields, m2m_fields
 
-    # Define BASE CRUD
-    def _crud_add_obj(self, **payload: Dict) -> Any:
-        local_f_payload, m2m_f_payload = self.__separate_payload(payload)
-        # Create obj with local_fields payload
-        obj = self.model.objects.create(**local_f_payload)
-        # Save obj with m2m_fields payload
-        if m2m_f_payload:
-            for _field, _value in m2m_f_payload.items():
+    @staticmethod
+    def _crud_set_m2m_obj(obj: models.Model, m2m_fields: Dict) -> None:
+        if obj and m2m_fields:
+            for _field, _value in m2m_fields.items():
                 if _value and isinstance(_value, List):
                     m2m_f = getattr(obj, _field)
                     m2m_f.set(_value)
-        return obj
 
-    def _crud_del_obj(self, pk: int) -> "BaseApiResponse":
+    # Define BASE CRUD
+    @transaction.atomic()
+    def _crud_add_obj(self, **payload: Dict) -> Any:
+        local_f_payload, m2m_f_payload = self._separate_payload(payload)
+
+        try:
+            # Create obj with local_fields payload
+            obj = self.model.objects.create(**local_f_payload)
+            # Save obj with m2m_fields payload
+            self._crud_set_m2m_obj(obj, m2m_f_payload)
+        except Exception as e:  # pragma: no cover
+            raise BaseAPIException(f"Create Error - {e}")
+        if obj:
+            return obj.id
+
+    def _crud_del_obj(self, pk: int) -> bool:
         obj = get_object_or_none(self.model, pk=pk)
         if obj:
             self.model.objects.filter(pk=pk).delete()
-            return BaseApiResponse({"Detail": "Deleted."})
+            return True
         else:
-            return BaseApiResponse({"Detail": "Not found."}, message="Not found.")
+            return False
 
-    def _crud_update_obj(self, pk: int, payload: Dict) -> "BaseApiResponse":
-        local_fields, m2m_fields = self.__separate_payload(payload)
+    @transaction.atomic()
+    def _crud_update_obj(self, pk: int, payload: Dict) -> bool:
+        local_fields, m2m_fields = self._separate_payload(payload)
+        if not self.model.objects.filter(pk=pk).exists():
+            return False
         try:
-            obj, created = self.model.objects.update_or_create(
-                pk=pk, defaults=local_fields
-            )
+            obj, _ = self.model.objects.update_or_create(pk=pk, defaults=local_fields)
+            self._crud_set_m2m_obj(obj, m2m_fields)
         except Exception as e:  # pragma: no cover
-            logger.error(f"Crud_update Error - {e}", exc_info=True)
-            return BaseApiResponse(message="Failed")
-        if m2m_fields:
-            for _field, _value in m2m_fields.items():
-                if _value:
-                    m2m_f = getattr(obj, _field)
-                    m2m_f.set(_value)
-        return BaseApiResponse({"id": obj.id, "created": created})
+            raise BaseAPIException(f"Update Error - {e}")
+        return bool(obj)
 
     def _crud_get_obj(self, pk: int) -> Any:
         if self.m2m_fields_list:
@@ -78,7 +97,6 @@ class CrudModel(object):
             qs = self.model.objects.filter(pk=pk)
         if qs:
             return qs.first()
-        return BaseApiResponse()
 
     def _crud_get_objs_all(self, maximum: int = None, **filters: Any) -> Any:
         """
@@ -108,7 +126,7 @@ class CrudModel(object):
         return qs
 
     def _crud_filter(self, **kwargs: Any) -> QuerySet:
-        return self.model.objects.filter(**kwargs)
+        return self.model.objects.filter(**kwargs)  # pragma: no cover
 
     def _crud_filter_exclude(self, **kwargs: Any) -> QuerySet:
         return self.model.objects.all().exclude(**kwargs)
